@@ -13,10 +13,16 @@ sub import {
 
     *::ok = *ok;
     *::is = *ok;
+    *::roundtrip = *roundtrip;
     *::Dump = *YAML::Syck::Dump;
     *::Load = *YAML::Syck::Load;
 }
 
+sub roundtrip {
+    @_ = (YAML::Syck::Load(YAML::Syck::Dump($_[0])), $_[0]);
+    goto &main::is;
+}
+
 1;
 
 #use Test::YAML 0.51 -Base;
